#include <iostream>
#include <vector>
using namespace std;

typedef long long ll;
const ll INF = 1e18;

int main() {
    ios::sync_with_stdio(false);
    cin.tie(nullptr);

    int n, m;
    cin >> n >> m;
    vector<vector<int>> adj(n, vector<int>(n, (int)1e9));
    for(int i = 0; i < m; i++) {
        int u, l, r;
        cin >> u >> l >> r;
        u--;
        l--;
        r--;
        for(int v = l; v <= r; v++) {
            int w = v - l + 1;
            adj[u][v] = min(adj[u][v], w);
        }
    }

    // Use the classical O(n^2) Dijkstra (without using a priority queue).
    vector<ll> dist(n, INF);
    vector<bool> used(n, false);
    dist[0] = 0;  // start at vertex 0 (i.e. vertex 1 in problem)

    for(int i = 0; i < n; i++) {
        int u = -1;
        // Find the unused vertex with minimum distance.
        for(int j = 0; j < n; j++) {
            if(!used[j] && (u == -1 || dist[j] < dist[u])) {
                u = j;
            }
        }

        if(u == -1 || dist[u] == INF) {
            break;
        }
        used[u] = true;

        // Relax edges from vertex u.
        for(int v = 0; v < n; v++) {
            if(adj[u][v] <= n && dist[v] > dist[u] + adj[u][v]) {
                dist[v] = dist[u] + adj[u][v];
            }
        }
    }

    // Print the result.
    for(int i = 0; i < n; i++) {
        if(dist[i] == INF) {
            cout << -1 << " ";
        } else {
            cout << dist[i] << " ";
        }
    }
    cout << "\n";

    return 0;
}
