#include <iostream>
#include <queue>
#include <vector>
using namespace std;

typedef long long ll;
const ll INF = 1e18;

int main() {
    ios::sync_with_stdio(false);
    cin.tie(nullptr);

    int n, m;
    cin >> n >> m;
    // Build the uncompressed graph: for every compressed edge, add one edge per
    // vertex in [l, r]. Note: vertices in input are 1-indexed; we convert to
    // 0-indexed.
    vector<vector<pair<int, int>>> adj(n);
    for(int i = 0; i < m; i++) {
        int u, l, r;
        cin >> u >> l >> r;
        u--;
        l--;
        r--;
        for(int v = l; v <= r; v++) {
            int w = v - l +
                    1;  // weight increases by 1 for each vertex in the range
            adj[u].push_back({v, w});
        }
    }

    // Run Dijkstra from vertex 0 (which corresponds to vertex 1 in the
    // problem).
    vector<ll> dist(n, INF);
    dist[0] = 0;
    // (distance, vertex)
    priority_queue<pair<ll, int>, vector<pair<ll, int>>, greater<pair<ll, int>>>
        pq;
    pq.push({0, 0});

    while(!pq.empty()) {
        auto [d, u] = pq.top();
        pq.pop();
        if(d != dist[u]) {
            continue;
        }
        for(auto& edge: adj[u]) {
            int v = edge.first;
            int w = edge.second;
            if(dist[v] > d + w) {
                dist[v] = d + w;
                pq.push({dist[v], v});
            }
        }
    }

    // Output distances (if unreachable, output -1)
    for(int i = 0; i < n; i++) {
        if(dist[i] == INF) {
            cout << -1 << " ";
        } else {
            cout << dist[i] << " ";
        }
    }
    cout << "\n";

    return 0;
}
