#include <bits/stdc++.h>
using namespace std;

const int64_t inf = (int64_t)1e18 + 42;

template<class T, bool (*cmp)(T, T)>
class Heap {
  private:
    vector<T> heap_values;
    vector<int> heap, pos_in_heap;

    void push_up(int id) {
        while(id > 0 &&
              cmp(heap_values[heap[id]], heap_values[heap[(id - 1) / 2]])) {
            swap(heap[id], heap[(id - 1) / 2]);
            swap(pos_in_heap[heap[id]], pos_in_heap[heap[(id - 1) / 2]]);
            id = (id - 1) / 2;
        }
    }

    void push_down(int id) {
        while(2 * id + 1 < heap.size()) {
            int child = 2 * id + 1;
            if(child + 1 < heap.size() &&
               cmp(heap_values[heap[child + 1]], heap_values[heap[child]])) {
                child++;
            }
            if(cmp(heap_values[heap[id]], heap_values[heap[child]])) {
                break;
            }
            swap(heap[id], heap[child]);
            swap(pos_in_heap[heap[id]], pos_in_heap[heap[child]]);
            id = child;
        }
    }

  public:
    Heap() { clear(); }

    void clear() {
        heap.clear();
        heap_values.clear();
        pos_in_heap.clear();
    }

    int push(T val) {
        heap.push_back(heap_values.size());
        pos_in_heap.push_back(heap.size() - 1);
        heap_values.push_back(val);
        push_up(heap.size() - 1);
        return heap_values.size() - 1;
    }

    T pop() {
        int ret_node = heap[0];
        swap(pos_in_heap[ret_node], pos_in_heap[heap.back()]);
        swap(heap[0], heap[heap.size() - 1]);
        heap.pop_back();
        pos_in_heap[ret_node] = -1;
        if(heap.size() > 0) {
            push_down(0);
        }
        return heap_values[ret_node];
    }

    size_t size() { return heap.size(); }
    bool empty() { return heap.size() == 0; }

    T top() { return heap_values[heap[0]]; }

    int top_node() { return heap[0]; }

    void update(int node, T val) {
        int p = pos_in_heap[node];
        bool is_push_down = cmp(heap_values[node], val);

        if(is_push_down) {
            heap_values[node] = val;
            push_down(p);
        } else {
            heap_values[node] = val;
            push_up(p);
        }
    }
};

int n, m, real_n;
vector<tuple<int, int, int>> edges;
vector<vector<pair<int, int>>> adj;

void read() {
    cin >> n >> m;
    adj.assign(5 * n + 1, {});
    real_n = n;

    for(int i = 0; i < m; i++) {
        int u, l, r;
        cin >> u >> l >> r;
        u--, l--, r--;
        edges.emplace_back(u, l, r);
    }
}

vector<int> node;

int build_tree_struct(int l, int r, int idx) {
    if(l == r) {
        int v = n++;
        adj[v].push_back({l, 1});
        return node[idx] = v;
    }

    int mid = (l + r) / 2;
    int v = n++;
    adj[v].push_back({build_tree_struct(l, mid, 2 * idx + 1), 0});
    adj[v].push_back({build_tree_struct(mid + 1, r, 2 * idx + 2), mid - l + 1});
    return node[idx] = v;
}

void add_edges(int u, int ql, int qr, int l, int r, int idx) {
    if(ql > r || qr < l) {
        return;
    }
    if(ql <= l && r <= qr) {
        adj[u].push_back({node[idx], l - ql});
        return;
    }

    int mid = (l + r) / 2;
    add_edges(u, ql, qr, l, mid, 2 * idx + 1);
    add_edges(u, ql, qr, mid + 1, r, 2 * idx + 2);
}

bool cmp_min(int64_t a, int64_t b) { return a < b; }

vector<int64_t> dijkstra(int start) {
    vector<int64_t> dist(n, inf);
    vector<int> pq_node(n, -1);
    vector<int> pq_node_to_ver(n, -1);
    Heap<int64_t, cmp_min> pq;

    function<void(int, int64_t)> update = [&](int u, int64_t d) {
        dist[u] = min(dist[u], d);
        if(pq_node[u] == -1) {
            pq_node[u] = pq.push(dist[u]);
            pq_node_to_ver[pq_node[u]] = u;
        } else {
            pq.update(pq_node[u], dist[u]);
        }
    };

    update(start, 0);
    while(!pq.empty()) {
        int u = pq_node_to_ver[pq.top_node()];
        pq.pop();

        for(auto [v, w]: adj[u]) {
            update(v, dist[u] + w);
        }
    }

    return dist;
}

void solve() {
    node.resize(4 * real_n + 1);
    build_tree_struct(0, real_n - 1, 0);

    for(auto [u, l, r]: edges) {
        add_edges(u, l, r, 0, real_n - 1, 0);
    }

    vector<int64_t> ans = dijkstra(0);
    for(int i = 0; i < real_n; i++) {
        int64_t res = ans[i];
        if(res == inf) {
            cout << -1 << ' ';
        } else {
            cout << res << ' ';
        }
    }
    cout << '\n';
}

int main() {
    ios_base::sync_with_stdio(false);
    cin.tie(nullptr);

    read();
    solve();
    return 0;
}
