import random
import os


def generate_test_case(n, m):
    """
    Generate a test case for the compressed graph problem.
    - n: number of vertices.
    - m: number of compressed edges.
    Each compressed edge is generated by picking:
      * u uniformly in [1, n]
      * l uniformly in [1, n]
      * r uniformly in [l, n]
    """
    edges = []
    for _ in range(m):
        if _ < 3:
            u = 1
        else:
            u = random.randint(1, n)

        l = random.randint(1, n)
        r = random.randint(l, n)
        edges.append((u, l, r))
    return n, m, edges


def write_test_case(filename, n, m, edges):
    with open(filename, "w") as f:
        f.write(f"{n} {m}\n")
        for u, l, r in edges:
            f.write(f"{u} {l} {r}\n")


def generate_test_suite():
    # List of (n, m, cnt_tests) configurations.
    test_configs = [
        (10, 5, 1),
        (100, 200, 1),
        (1000, 2000, 3),
        (1000, 100, 5),
        (4000, 50000, 2),
        (4000, 100000, 3),
        (100000, 200000, 5),
        (100000, 100000, 2),
        (100000, 20000, 3),
    ]

    test_num = 1
    for n, m, cnt_tests in test_configs:
        for _ in range(cnt_tests):
            n_val, m_val, edges = generate_test_case(n, m)
            filename = os.path.join(
                os.path.dirname(os.path.abspath(__file__)),
                f"table.{str(test_num).zfill(2)}.in",
            )
            write_test_case(filename, n_val, m_val, edges)
            print(f"Generated {filename}")
            test_num += 1


if __name__ == "__main__":
    generate_test_suite()
